﻿IF OBJECT_ID('[xs_log_list]') IS NOT NULL DROP TABLE [xs_log_list]
GO

CREATE TABLE [xs_log_list] (
	[lid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_xs_log_list] PRIMARY KEY  CLUSTERED ([lid])  ON [PRIMARY],
	[uid] [int] NOT NULL DEFAULT (0),
	[ltype] [int] NOT NULL DEFAULT (0),
	[ldes] [nvarchar](255) NOT NULL DEFAULT (''),
	[lstatus] [int] NOT NULL DEFAULT (0),
	[ltime] [smalldatetime] NOT NULL DEFAULT (getdate()),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_xs_log_list] ON [xs_log_list]([uid] ASC,[ltype] ASC,[lstatus] ASC);
GO


IF OBJECT_ID('[xs_mail_list]') IS NOT NULL DROP TABLE [xs_mail_list]
GO

CREATE TABLE [xs_mail_list] (
	[mailid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_xs_mail_list] PRIMARY KEY  CLUSTERED ([mailid] ASC)  ON [PRIMARY],
	[uid] [int] NOT NULL DEFAULT (0),
	[vid] [int] NOT NULL DEFAULT (0),
	[subject] [nvarchar](100) NOT NULL DEFAULT (''),
	[to] [nvarchar](50) NOT NULL DEFAULT (''),
	[body] [nvarchar](4000) NOT NULL DEFAULT (''),
	[mtype] [int] NOT NULL DEFAULT (0),
	[mtime] [int] NOT NULL DEFAULT (0),
	[mstatus] [int] NOT NULL DEFAULT (0),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_xs_mail_list] ON [xs_mail_list] ([uid] ASC,[vid] ASC,[mtype] ASC,[mstatus] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_mail_list_to] ON [xs_mail_list] ([to] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_mail_list_time] ON [xs_mail_list] ([mtime] ASC);
GO



IF OBJECT_ID('[xs_user_list]') IS NOT NULL DROP TABLE [xs_user_list]
GO

CREATE TABLE [xs_user_list] (
	[id] [int] IDENTITY(1,1) NOT NULL,
	[uid] [int] NOT NULL DEFAULT (0) CONSTRAINT [PK_xs_user_list] PRIMARY KEY CLUSTERED ([id] ASC,[uid] ASC) ON [PRIMARY],
	[username] [varchar](50) NOT NULL DEFAULT (''),
	[password] [varchar](32) NOT NULL DEFAULT (''),
	[salt] [varchar](10) NOT NULL DEFAULT (''),
	[name] [nvarchar](50) NOT NULL DEFAULT (''),
	[email] [varchar](255) NOT NULL DEFAULT (''),
	[tel] [varchar](255) NOT NULL DEFAULT (''),
	[language] [int] NOT NULL DEFAULT (0),
	[vcount] [int] NOT NULL DEFAULT (0),
	[utype] [int] NOT NULL DEFAULT (0),
	[ustatus] [int] NOT NULL DEFAULT (0),
	[apikey] [varchar](255) NOT NULL DEFAULT (''),
	[adminps] [varchar](32) NOT NULL DEFAULT (''),
	[cvdate] [int] NOT NULL DEFAULT (0),
	[rvcount] [int] NOT NULL DEFAULT (0),
	[dvcount] [int] NOT NULL DEFAULT (0),
	[reg_ip] [varchar](50) NOT NULL DEFAULT (''),
	[login_ip] [varchar](50) NOT NULL DEFAULT (''),
	[regtime] [smalldatetime] NOT NULL DEFAULT (getdate()),
	[logintime] [smalldatetime] NOT NULL DEFAULT (getdate()),
	[uconfig] [nvarchar](2000) NOT NULL DEFAULT (''),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_user_name_email_tel] ON [xs_user_list] ([username] ASC,[name] ASC,[tel] ASC);
CREATE NONCLUSTERED INDEX [IX_user_lang_utype_status] ON [xs_user_list] ([language] ASC,[utype] ASC,[ustatus] ASC);
CREATE NONCLUSTERED INDEX [IX_user_ip] ON [xs_user_list] ([reg_ip] ASC,[login_ip] ASC);
GO

IF OBJECT_ID('[xs_utype_list]') IS NOT NULL DROP TABLE [xs_utype_list]
GO

CREATE TABLE [xs_utype_list] (
	[id] [int] IDENTITY(1,1) NOT NULL,
	[utype] [int] NOT NULL DEFAULT (0) CONSTRAINT [PK_xs_utype_list] PRIMARY KEY CLUSTERED ([id] ASC,[utype] ASC) ON [PRIMARY],
	[tname] [nvarchar](50) NOT NULL DEFAULT (''),
	[utconfig] [nvarchar](2000) NOT NULL DEFAULT (''),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_xs_utype_type] ON [xs_utype_list] ([utype] ASC);
GO


IF OBJECT_ID('[dc_list]') IS NOT NULL DROP TABLE [dc_list]
GO

CREATE TABLE [dc_list] (
	[did] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_dc_list] PRIMARY KEY  CLUSTERED ([did])  ON [PRIMARY],
	[dname] [varchar](50) NOT NULL DEFAULT (''),
	[scount] [int] NOT NULL DEFAULT (0),
	[dorder] [int] NOT NULL DEFAULT (0),
	[dpublic] [int] NOT NULL DEFAULT (0),
	[dconfig] [nvarchar](4000) NOT NULL DEFAULT (''),
	[dpool] [int] NOT NULL DEFAULT (0),
	[dmaster] [int] NOT NULL DEFAULT (0),
	[duuid] [varchar](50) NOT NULL DEFAULT (''),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_dc_list] ON [dc_list]([scount] ASC,[dpublic] ASC);
CREATE NONCLUSTERED INDEX [IX_dc_list_1] ON [dc_list]([dorder] ASC);
CREATE NONCLUSTERED INDEX [IX_dc_list_pool] ON [dc_list] ([dpool] ASC,[dmaster] ASC);
CREATE NONCLUSTERED INDEX [IX_dc_list_uuid] ON [dc_list] ([duuid] ASC);
GO

IF OBJECT_ID('[os_list]') IS NOT NULL DROP TABLE [os_list]
GO

CREATE TABLE [os_list] (
	[oid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_os_list] PRIMARY KEY  CLUSTERED ([oid])  ON [PRIMARY],
	[oname] [varchar](30) NOT NULL DEFAULT (''),
	[odes] [nvarchar](255) NOT NULL DEFAULT (''),
	[oorder] [int] NOT NULL DEFAULT (0),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_os_order] ON [os_list]([oorder] ASC);
GO


IF OBJECT_ID('[acode_list]') IS NOT NULL DROP TABLE [acode_list]
GO

CREATE TABLE [acode_list] (
	[acid] [int] NOT NULL CONSTRAINT [PK_acode_list] PRIMARY KEY  CLUSTERED ([acid])  ON [PRIMARY],
	[sip] [varchar](50) NOT NULL DEFAULT (''),
	[acode] [varchar](1000) NOT NULL  DEFAULT (''),
	[actime] [int] NOT NULL DEFAULT (0),
	[acstatus] [int] NOT NULL DEFAULT (0),
	[cycle] [int] NOT NULL DEFAULT (1),
	[etime] [int] NOT NULL DEFAULT (0),
	[setime] [int] NOT NULL DEFAULT (0),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_acode_list] ON [acode_list] ([sip] ASC);
CREATE NONCLUSTERED INDEX [IX_acode_list_1] ON [acode_list]([actime] ASC,[acstatus] ASC);
CREATE NONCLUSTERED INDEX [IX_acode_list_cycle] ON [acode_list] ([cycle] ASC);
CREATE NONCLUSTERED INDEX [IX_acode_list_etime] ON [acode_list] ([etime] ASC,[setime] ASC);
GO


IF OBJECT_ID('[server_list]') IS NOT NULL DROP TABLE [server_list]
GO

CREATE TABLE [server_list] (
	[sid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_server_list] PRIMARY KEY  CLUSTERED ([sid] ASC)  ON [PRIMARY],
	[did] [int] NOT NULL DEFAULT (0),
	[sname] [varchar](50) NOT NULL DEFAULT (''),
	[sip] [varchar](50) NOT NULL DEFAULT (''),
	[vcount] [int] NOT NULL DEFAULT (0),
	[sdes] [varchar](255) NOT NULL DEFAULT (''),
	[lstr] [varchar](255) NOT NULL DEFAULT (''),
	[maxcpu] [int] NOT NULL DEFAULT (0),
	[maxram] [int] NOT NULL DEFAULT (0),
	[maxdisk] [int] NOT NULL DEFAULT (0),
	[allowram] [int] NOT NULL DEFAULT (0),
	[allowdisk] [int] NOT NULL DEFAULT (0),
	[sorder] [int] NOT NULL DEFAULT (0),
	[os] [varchar](50) NOT NULL DEFAULT (''),
	[creattime] [smalldatetime] NOT NULL DEFAULT (getdate()),
	[sstatus] [int] NOT NULL DEFAULT (0),
	[uptime] [varchar](255) NOT NULL DEFAULT (''),
	[sconfig] [varchar](50) NOT NULL DEFAULT ('0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0'),
	[suuid] [varchar](50) NOT NULL DEFAULT (''),
	[ha] [int] NOT NULL DEFAULT (0),
	[lb] [int] NOT NULL DEFAULT (0),
	[fcount] [int] NOT NULL DEFAULT (0),
	[serverconfig] [nvarchar](4000) NOT NULL DEFAULT (''),
	[vnc_server] [int] NOT NULL DEFAULT (0),
	[vnc_port] [int] NOT NULL DEFAULT (0),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_server_list] ON [server_list]([did] ASC,[sstatus] ASC);
CREATE NONCLUSTERED INDEX [IX_server_list_1] ON [server_list]([sname] ASC,[sip] ASC,[os] ASC);
CREATE NONCLUSTERED INDEX [IX_server_list_2] ON [server_list]([sorder] ASC,[allowram] ASC,[allowdisk] ASC);
CREATE NONCLUSTERED INDEX [IX_server_list_uuid] ON [server_list] ([suuid] ASC);
CREATE NONCLUSTERED INDEX [IX_server_list_ha_lb] ON [server_list] ([ha] ASC,[lb] ASC,[fcount] ASC);
CREATE NONCLUSTERED INDEX [IX_server_list_vnc] ON [server_list] ([vnc_server] ASC, [vnc_port] ASC);
GO


IF OBJECT_ID('[ip_blocks]') IS NOT NULL DROP TABLE [ip_blocks]
GO

CREATE TABLE [ip_blocks] (
	[bid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_ip_blocks] PRIMARY KEY  CLUSTERED ([bid])  ON [PRIMARY],
	[sid] [int] NOT NULL DEFAULT (0),
	[gateway] [varchar](20) NOT NULL DEFAULT (''),
	[netmask] [varchar](20) NOT NULL DEFAULT (''),
	[btype] [int] NOT NULL DEFAULT (0),
	[bconfig] [nvarchar](255) NOT NULL DEFAULT (''),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_ip_blocks] ON [ip_blocks]([sid] ASC);
CREATE NONCLUSTERED INDEX [IX_ip_blocks_1] ON [ip_blocks]([gateway] ASC);
CREATE NONCLUSTERED INDEX [IX_ip_blocks_btype] ON [ip_blocks]([btype] ASC);
GO


IF OBJECT_ID('[ip_list]') IS NOT NULL DROP TABLE [ip_list]
GO

CREATE TABLE [ip_list] (
	[iid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_ip_list] PRIMARY KEY  CLUSTERED ([iid])  ON [PRIMARY],
	[sid] [int] NOT NULL DEFAULT (0),
	[bid] [int] NOT NULL DEFAULT (0),
	[vid] [int] NOT NULL DEFAULT (0),
	[itype] [int] NOT NULL DEFAULT (0),
	[ip] [varchar](20) NOT NULL DEFAULT (''),
	[addtime] [smalldatetime] NOT NULL DEFAULT (getdate()),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_ip_list] ON [ip_list]([sid] ASC,[bid] ASC,[vid] ASC,[itype] ASC);
CREATE NONCLUSTERED INDEX [IX_ip_list_1] ON [ip_list]([ip] ASC);
GO


IF OBJECT_ID('[bw_list]') IS NOT NULL DROP TABLE [bw_list]
GO

CREATE TABLE [bw_list] (
	[bid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_bw_list] PRIMARY KEY  CLUSTERED ([bid])  ON [PRIMARY],
	[uid] [int] NOT NULL DEFAULT (0),
	[vid] [int] NOT NULL DEFAULT (0),
	[sdate] [smalldatetime] NOT NULL DEFAULT (getdate() - (30)),
	[edate] [smalldatetime] NOT NULL DEFAULT (getdate()),
	[bw] [bigint] NOT NULL DEFAULT (0),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_bw_list] ON [bw_list]([uid] ASC,[vid] ASC);
GO

IF OBJECT_ID('[xs_vps_group]') IS NOT NULL DROP TABLE [xs_vps_group]
GO

CREATE TABLE [xs_vps_group] (
	[gid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_xs_vps_group] PRIMARY KEY  CLUSTERED ([gid] ASC) ON [PRIMARY],
	[uid] [int] NOT NULL DEFAULT (0),
	[gname] [nvarchar](100) NOT NULL DEFAULT (''),
	[vcount] [int] NOT NULL DEFAULT (0),
	[gconfig] [nvarchar](4000) NOT NULL DEFAULT (''),
	[gorder] [int] NOT NULL DEFAULT (0),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_xs_vps_group_uid] ON [xs_vps_group] ([uid] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_vps_group_gname] ON [xs_vps_group] ([gname] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_vps_group_order] ON [xs_vps_group] ([vcount] ASC,[gorder] ASC);
GO


IF OBJECT_ID('[vps_list]') IS NOT NULL DROP TABLE [vps_list]
GO

CREATE TABLE [vps_list] (
	[vid] [int] IDENTITY(868,1) NOT NULL CONSTRAINT [PK_vps_list] PRIMARY KEY  CLUSTERED ([vid] ASC)  ON [PRIMARY],
	[uid] [int] NOT NULL DEFAULT (0),
	[did] [int] NOT NULL DEFAULT (0),
	[sid] [int] NOT NULL DEFAULT (0),
	[vos] [varchar](30) NOT NULL DEFAULT (''),
	[vname] [varchar](50) NOT NULL DEFAULT (''),
	[vmac] [varchar](20) NOT NULL DEFAULT (''),
	[vip] [varchar](20) NOT NULL DEFAULT (''),
	[vcpu] [int] NOT NULL DEFAULT (1),
	[vram] [int] NOT NULL DEFAULT (256),
	[vdisk] [int] NOT NULL DEFAULT (10),
	[vbandwidth] [int] NOT NULL DEFAULT (100),
	[cbandwidth] [bigint] NOT NULL DEFAULT (0),
	[lbandwidth] [bigint] NOT NULL DEFAULT (0),
	[tbandwidth] [bigint] NOT NULL DEFAULT (0),
	[vdes] [varchar](1000) NOT NULL DEFAULT (''),
	[vstatus] [int] NOT NULL DEFAULT (0),
	[creattime] [smalldatetime] NOT NULL DEFAULT (getdate()),
	[bwdate] [smalldatetime] NOT NULL DEFAULT (getdate()),
	[ver] [int] NOT NULL DEFAULT (0),
	[vpass] [varchar](50) NOT NULL DEFAULT (''),
	[vport] [int] NOT NULL DEFAULT (0),
	[ucpu] [float] NOT NULL DEFAULT (0),
	[uio] [bigint] NOT NULL DEFAULT (0),
	[net_tx] [bigint] NOT NULL DEFAULT (0),
	[net_rx] [bigint] NOT NULL DEFAULT (0),
	[vbd_rd] [bigint] NOT NULL DEFAULT (0),
	[vbd_wr] [bigint] NOT NULL DEFAULT (0),
	[rprice] [int] NOT NULL DEFAULT (0),
	[dpass] [varchar](20) NOT NULL DEFAULT (''),
	[uuid] [varchar](50) NOT NULL DEFAULT (''),
	[domid] [int] NOT NULL DEFAULT (0),
	[vpsinfo] [varchar](1000) NOT NULL DEFAULT (''),
	[gid] [int] NOT NULL DEFAULT (0),
	[vconfig] [nvarchar](4000) NOT NULL DEFAULT (''),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_vps_list] ON [vps_list]([uid] ASC,[did] ASC,[sid] ASC,[vstatus] ASC);
CREATE NONCLUSTERED INDEX [IX_vps_list_1] ON [vps_list]([bwdate] ASC);
CREATE NONCLUSTERED INDEX [IX_vps_list_2] ON [vps_list]([vname] ASC,[vmac] ASC,[vip] ASC);
CREATE NONCLUSTERED INDEX [IX_vps_list_3] ON [vps_list]([cbandwidth] ASC,[lbandwidth] ASC,[tbandwidth] ASC,[ucpu] ASC,[uio] ASC);
CREATE NONCLUSTERED INDEX [IX_vps_list_uuid] ON [vps_list] ([uuid] ASC);
CREATE NONCLUSTERED INDEX [IX_vps_list_domid] ON [vps_list] ([domid] ASC);
CREATE NONCLUSTERED INDEX [IX_vps_list_gid] ON [vps_list] ([gid] ASC);
GO

IF OBJECT_ID('[xs_vps_fields]') IS NOT NULL DROP TABLE [xs_vps_fields]
GO

CREATE TABLE [xs_vps_fields] (
	[fid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_xs_vps_fields] PRIMARY KEY  CLUSTERED ([fid] ASC) ON [PRIMARY],
	[vid] [int] NOT NULL DEFAULT (0),
	[uid] [int] NOT NULL DEFAULT (0),
	[ftype] [int] NOT NULL DEFAULT (0),
	[fstatus] [int] NOT NULL DEFAULT (0),
	[fname] [varchar](100) NOT NULL DEFAULT (''),
	[fvalue] [nvarchar](255) NOT NULL DEFAULT (''),
	[fconfig] [nvarchar](4000) NOT NULL DEFAULT (''),
	[forder] [int] NOT NULL DEFAULT (0),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_xs_vps_fields_int] ON [xs_vps_fields] ([vid] ASC,[uid] ASC,[ftype] ASC,[fstatus] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_vps_fields_char] ON [xs_vps_fields] ([fname] ASC,[fvalue] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_vps_fields_order] ON [xs_vps_fields] ([forder] ASC);
GO


IF OBJECT_ID('[xs_task_list]') IS NOT NULL DROP TABLE [xs_task_list]
GO

CREATE TABLE [xs_task_list] (
	[tid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_xs_task_list] PRIMARY KEY  CLUSTERED ([tid] ASC)  ON [PRIMARY],
	[ttype] [int] NOT NULL DEFAULT (0),
	[uid] [int] NOT NULL DEFAULT (0),
	[sid] [int] NOT NULL DEFAULT (0),
	[vid] [int] NOT NULL DEFAULT (0),
	[tinfo] [varchar](500) NOT NULL DEFAULT (''),
	[tstatus] [int] NOT NULL DEFAULT (0),
	[ttime] [int] NOT NULL DEFAULT (0),
	[tmsg] [nvarchar](255) NOT NULL DEFAULT (''),
	[subtask_count] [int] NOT NULL DEFAULT (0),
	[maintask] [int] NOT NULL DEFAULT (0),
	[substatus] [int] NOT NULL DEFAULT (0),
	[rtime] [int] NOT NULL DEFAULT (0),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_xs_task_list] ON [xs_task_list] ([ttype] ASC,[uid] ASC,[sid] ASC,[vid] ASC,[tstatus] ASC,[ttime] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_task_list_sub] ON [xs_task_list] ([subtask_count] ASC,[maintask] ASC,[substatus] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_task_list_rtime] ON [xs_task_list] ([rtime] ASC);
GO


IF OBJECT_ID('[xs_config_list]') IS NOT NULL DROP TABLE [xs_config_list]
GO

CREATE TABLE [xs_config_list] (
	[cid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_xs_config_list] PRIMARY KEY  CLUSTERED ([cid] ASC)  ON [PRIMARY],
	[ctype] [int] NOT NULL DEFAULT (0),
	[disabled] [int] NOT NULL DEFAULT (0),
	[cname] [varchar](50) NOT NULL DEFAULT (''),
	[cvalue] [varchar](500) NOT NULL DEFAULT (''),
	[cconfig] [nvarchar](4000) NOT NULL DEFAULT (''),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_config_ctype_disabled] ON [xs_config_list] ([ctype] ASC,[disabled] ASC);
CREATE NONCLUSTERED INDEX [IX_config_cname] ON [xs_config_list] ([cname] ASC);
GO


IF OBJECT_ID('[xs_stat_list]') IS NOT NULL DROP TABLE [xs_stat_list]
GO

CREATE TABLE [xs_stat_list] (
	[id] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_xs_stat_list] PRIMARY KEY  CLUSTERED ([id] ASC) ON [PRIMARY],
	[interval] [int] NOT NULL DEFAULT (0),
	[stype] [int] NOT NULL DEFAULT (0),
	[serverid] [int] NOT NULL DEFAULT (0),
	[vpsid] [int] NOT NULL DEFAULT (0),
	[uuid] [varchar](50) NOT NULL DEFAULT (''),
	[device] [varchar](50) NOT NULL DEFAULT (''),
	[stime] [int] NOT NULL DEFAULT (0),
	[etime] [int] NOT NULL DEFAULT (0),
	[svalue] [varchar](8000) NOT NULL DEFAULT (''),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_xs_stat_list_int] ON [xs_stat_list] ([interval] ASC,[stype] ASC,[serverid] ASC,[vpsid] ASC,[stime] ASC,[etime] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_stat_list_uuid] ON [xs_stat_list] ([uuid] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_stat_list_device] ON [xs_stat_list] ([device] ASC);
GO

IF OBJECT_ID('[xs_tracker_list]') IS NULL
BEGIN
CREATE TABLE [xs_tracker_list] (
	[tid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_xs_tracker_list] PRIMARY KEY CLUSTERED ([tid] ASC)  ON [PRIMARY],
	[uid] [int] NOT NULL DEFAULT (0),
	[id] [int] NOT NULL DEFAULT (0),
	[tip] [varchar](50) NOT NULL DEFAULT (''),
	[tdes] [nvarchar](255) NOT NULL DEFAULT (''),
	[ttime] [int] NOT NULL DEFAULT (0),
	[tdatetime] [smalldatetime] NOT NULL DEFAULT (getdate()),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_xs_tracker_list_id] ON [xs_tracker_list] ([uid] ASC,[id] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_tracker_list_ip] ON [xs_tracker_list] ([tip] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_tracker_list_des] ON [xs_tracker_list] ([tdes] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_tracker_list_time] ON [xs_tracker_list] ([ttime] ASC);
END

IF OBJECT_ID('[xs_vnetwork_list]') IS NULL
BEGIN
CREATE TABLE [xs_vnetwork_list] (
	[vnid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_xs_vnetwork_list] PRIMARY KEY CLUSTERED ([vnid] ASC)  ON [PRIMARY],
	[uid] [int] NOT NULL DEFAULT (0),
	[sid] [int] NOT NULL DEFAULT (0),
	[vnuuid] [varchar](50) NOT NULL DEFAULT (''),
	[vids] [varchar](1000) NOT NULL DEFAULT ('0'),
	[vnconfig] [nvarchar](4000) NOT NULL DEFAULT (''),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_xs_vnetwork_id] ON [xs_vnetwork_list] ([uid] ASC,[sid] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_vnetwork_uuid] ON [xs_vnetwork_list] ([vnuuid] ASC);
END

IF OBJECT_ID('[xs_vstorage_list]') IS NULL
BEGIN
CREATE TABLE [xs_vstorage_list] (
	[vsid] [int] IDENTITY(1,1) NOT NULL CONSTRAINT [PK_xs_vstorage_list] PRIMARY KEY CLUSTERED ([vsid] ASC)  ON [PRIMARY],
	[uid] [int] NOT NULL DEFAULT (0),
	[sid] [int] NOT NULL DEFAULT (0),
	[vssize] [int] NOT NULL DEFAULT (0),
	[vsstatus] [int] NOT NULL DEFAULT (0),
	[vsuuid] [varchar](50) NOT NULL DEFAULT (''),
	[vids] [varchar](1000) NOT NULL DEFAULT ('0'),
	[vsconfig] [nvarchar](4000) NOT NULL DEFAULT (''),
) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_xs_vstorage_id] ON [xs_vstorage_list] ([uid] ASC,[sid] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_vstorage_size_status] ON [xs_vstorage_list] ([vssize] ASC,[vsstatus] ASC);
CREATE NONCLUSTERED INDEX [IX_xs_vstorage_uuid] ON [xs_vstorage_list] ([vsuuid] ASC);
END

insert into [xs_utype_list] (utype,tname,utconfig) values ('0','Users','{"enable_api":"0","backup_snapshot":"2","backup_full":"2","backup_hours":"0,1,2,3","port_map":"0","binding_domain":"0","olimit_object":"0","olimit_cycle":"1","olimit_reload":"0","olimit_backup_restore":"0"}');
insert into [xs_utype_list] (utype,tname,utconfig) values ('100','Administrators','{"enable_api":"0","backup_snapshot":"10","backup_full":"10","backup_hours":"0,1,2,3","port_map":"0","binding_domain":"0","olimit_object":"0","olimit_cycle":"1","olimit_reload":"0","olimit_backup_restore":"0"}');
insert into [xs_config_list] (cname,cvalue) values ('template_path','/files/templates/default');
insert into [xs_config_list] (cname) values ('vnc_server_setting');
insert into [xs_config_list] (cname,cvalue) values ('os_tp_size','10');
insert into [xs_config_list] (cname,cvalue) values ('vps_config','{"create_vps_timeout":"20","stat_update_time":"10"}');
insert into [xs_config_list] (cname,cvalue) values ('api_key','');
insert into [xs_config_list] (cname,cvalue) values ('api_ips','');
insert into [xs_config_list] (cname,cvalue) values ('clientid','');
insert into [xs_config_list] (cname,cvalue) values ('hostkey','');
insert into [xs_config_list] (cname,cvalue) values ('admin_email','admin@mail.com');
insert into [xs_config_list] (cname,cvalue) values ('idc_name','CloudGoing Inc.');
insert into [xs_config_list] (cname,cvalue) values ('idc_url','http://www.cloudgoing.com/');
insert into [xs_config_list] (cname,cvalue) values ('support_url','http://demo.idcsystem.net/');
insert into [xs_config_list] (cname,cvalue) values ('homepage_url','');
insert into [xs_config_list] (cname,cvalue) values ('smtp','{"smtp_server":"smtp.gmail.com","smtp_account":"mail@gmail.com","smtp_password":"888888"}');
insert into [xs_config_list] (cname,cvalue) values ('sms_balance','0');
insert into [xs_config_list] (cname,cvalue) values ('send_messages','');
insert into [xs_config_list] (cname,cvalue) values ('site_status','{"status":"0","msg":""}');
insert into [xs_config_list] (cname,cvalue) values ('dversion','201406201133');
GO
